@@ -1,13 +1,14 @@
 """YamlConfig - ``ImportConfig`` subclass for loading YAML files."""
+from __future__ import print_function
+from __future__ import unicode_literals
 
-from __future__ import print_function, unicode_literals
 
 try:
     import yaml
-except ImportError as e:
+except ImportError as exc_info:
     print('******************************************************')
     print('Ignore this message if you are installing ImportConfig')
-    print('ImportError: {}'.format(e))
+    print('ImportError: {}'.format(exc_info))
     print('******************************************************')
 
 from . import ImportConfig
